@@ -1,5 +1,7 @@
 import json
 
+from panda_python_kit.comm.comm import nested_to_dict
+
 
 class ResultModel:
     def __init__(self,success=True,data=None,message=""):
@@ -14,17 +16,7 @@ class ResultModel:
         return json.dumps(self.to_dict())
 
     def to_dict(self):
-        data_dict = self.data
-        if self.data:
-            if hasattr(self.data, "to_dict"):
-                data_dict = self.data.to_dict()
-            elif isinstance(self.data, list):
-                data_dict = []
-                for item in self.data:
-                    if hasattr(item, "to_dict"):
-                        data_dict.append(item.to_dict())
-                    else:
-                        data_dict.append(item)
+        data_dict = nested_to_dict(self.data)
         return {
             "success": self.success,
             "data": data_dict,
@@ -32,3 +24,5 @@ class ResultModel:
         }
 
 
+
+
